@@ -1,5 +1,5 @@
-from mongonow.parser.filter_parser import FilterParser
-from mongonow.utils.json_manager import JsonManager
+from mongonow.filter_parser import FilterParser
+from mongonow.json_manager import JsonManager
 
 class Collection(list):
     def __init__(self, name, path):
